*******************************************************
********************** DATA PATH **********************
*******************************************************

*** insert below the path to the folder where you copy the replication archive

global dir_data = 	"  "



use "$dir_data/Data/LTIM.dta", clear 

xtset id time

set more off, permanently

label variable post_ref "Post_ref"
label variable treat_post "EU*post_ref"
label variable log_GDP "GDP (log)"
label variable Unemployment_ "Unemployment"

*********************************************************************************************************************************************************************
//TABLE 5
*********************************************************************************************************************************************************************
reg l_all_reasons EU post_ref treat_post, vce(robust)
reg l_all_reasons EU post_ref treat_post i.id, vce(robust)
reg l_all_reasons EU post_ref treat_post i.id l4.log_GDP l4.Unemployment, vce(robust)
reg l_all_reasons treat_post i.id i.time, vce(robust)

*********************************************************************************************************************************************************************
//TABLE 6 
*********************************************************************************************************************************************************************
//Total EU (panel 1)
reg l_all_reasons treat_post i.id i.time, vce(robust)
reg l_work_related treat_post i.id i.time, vce(robust)
reg l_family treat_post i.id i.time, vce(robust)
reg l_study treat_post i.id i.time, vce(robust)

//European Union EU15 (panel 2)
reg l_all_reasons EU2_post i.id i.time, vce(robust)
reg l_work_related EU2_post i.id i.time, vce(robust)
reg l_family EU2_post i.id i.time, vce(robust)
reg l_study EU2_post i.id i.time, vce(robust)

//European Union new (panel 3)
reg l_all_reasons EU3_post i.id i.time, vce(robust)
reg l_work_related EU3_post i.id i.time, vce(robust)
reg l_family EU3_post i.id i.time, vce(robust)
reg l_study EU3_post i.id i.time, vce(robust)

*********************************************************************************************************************************************************************
//TABLE 8 
*********************************************************************************************************************************************************************
//Total EU (panel 1)
reg l_outflow treat_post i.id i.time, vce(robust)
reg l_out_work treat_post i.id i.time, vce(robust)
reg l_out_family treat_post i.id i.time, vce(robust)
reg l_out_study treat_post i.id i.time, vce(robust)

//European Union EU15 (panel 2)
reg l_outflow  EU2_post i.id i.time, vce(robust)
reg l_out_work EU2_post i.id i.time, vce(robust)
reg l_out_family EU2_post i.id i.time, vce(robust)
reg l_out_study EU2_post i.id i.time, vce(robust)

//European Union new (panel 3)
reg l_outflow  EU3_post i.id i.time, vce(robust)
reg l_out_work EU3_post i.id i.time, vce(robust)
reg l_out_family EU3_post i.id i.time, vce(robust)
reg l_out_study EU3_post i.id i.time, vce(robust)


*******************************************************************************************************************************************************************
//TABLE 9
*******************************************************************************************************************************************************************

reg l_net_mig treat_post i.id i.time, vce(robust)
reg l_net_mig EU2_post i.id i.time, vce(robust)
reg l_net_mig EU3_post i.id i.time, vce(robust)

*******************************************************************************************************************************************************************
//TABLE 10
*****************************************************************************************************************************************************************
// panel 1

xtset id time

reg l_all_reasons post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_work_related post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_family post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_study post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)

// panel 3

reg l_outflow post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_out_work post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_out_family post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_out_study post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)


//panel 4

reg l_net_mig post_ref l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)

// panel 5
reg l_all_reasons post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_work_related post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_family post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_study post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)

// panel 6
gen all_other = work_related+family+study
gen l_other = ln(1+all_other)

replace l_other = ln(1+l_other)

reg l_other post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_work_related post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_family post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_study post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)

// panel 8

reg l_outflow post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_out_work post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_out_family post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)
reg l_out_study post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)


// panel 9

reg l_net_mig post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)

// panel 10

gen net_other = all_other-outflow
gen l_net_other = ln(1+net_other)

reg l_net_other post_ref l4.log_GDP l4.Unemployment i.id if EU == 0, vce(robust)

*****************************************************************************************************************************************************************
//TABLE 12, column 1
*****************************************************************************************************************************************************************

collapse (sum) work_related, by(date time EU)
 
drop if date < 19329
xtset EU date, daily

merge 1:1 EU time using "$dir_data\Data\health.dta"

gen health = Healthsector/1000

gen work = work-health

replace work = work_related if EU == 1

drop if time == 5 | time == 32

gen post_ref = 1
replace post_ref = 0 if date < 20607

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1

gen l_work = ln(work)

gen treat_post = EU*post_ref

xtset EU time
eststo c: reg l_work EU post_ref treat_post i.time, vce(robust)

//to replicate columns 2 and 3 refer to the code for tables C9 and C10

*****************************************************************************************************************************************************************
//TABLE 11
*****************************************************************************************************************************************************************

gen EU5 = EU3
replace EU5 = 0 if EU2 == 1

gen EU5_post = EU5*post_ref

label variable EU5 "EU_new"
label variable EU5_post "EU_new*post_ref"


reg l_all_reasons EU5_post l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_work_related EU5_post l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_family EU5_post l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)
reg l_study EU5_post l4.log_GDP l4.Unemployment i.id if EU == 1, vce(robust)

****************************************************************************************************************************************************************
//TABLE 13
****************************************************************************************************************************************************************

merge m:1 time using "$dir_data\vacancies.dta", gen(_m2)

xtset id time

reg l_all_reasons EU post_ref treat_post l4.log_GDP l4.Unemployment i.id, vce(robust)
reg l_all_reasons EU post_ref treat_post l4.log_GDP l4.Unemployment l1.l_vac i.id, vce(robust)
reg l_all_reasons EU post_ref treat_post l4.log_GDP l4.Unemployment l2.l_vac i.id, vce(robust)
reg l_work_related EU post_ref treat_post l4.log_GDP l4.Unemployment i.id, vce(robust)
reg l_work_related EU post_ref treat_post l4.log_GDP l4.Unemployment l1.l_vac i.id, vce(robust)
reg l_work_related EU post_ref treat_post l4.log_GDP l4.Unemployment l2.l_vac i.id, vce(robust)

*****************************************************************************************************************************************************************
//TABLE 16
*****************************************************************************************************************************************************************

gen l_all_0 = ln(1+all_reasons_0)
gen l_work_0 = ln(1+work_0)
gen l_nwork_0 = ln(1+non_work_0)


foreach var in l_all_0 l_work_0 l_nwork_0 {
replace `var' = . if date < 19418
}

reg l_all_0 treat_post i.id i.time, vce(robust)
reg l_work_0 treat_post i.id i.time, vce(robust)
reg l_nwork_0 treat_post i.id i.time, vce(robust)


foreach var in all_reasons_fix work_fix non_work_fix{
gen l_`var' = log(1+`var')
replace `var' = . if date < 19418
}

reg l_all_reasons_fix treat_post i.id i.time, vce(robust)
reg l_work_fix treat_post i.id i.time, vce(robust) 
reg l_non_work_fix treat_post i.id i.time, vce(robust)


*****************************************************************************************************************************************************************
//Table B.5
*****************************************************************************************************************************************************************

foreach var in all_reasons work_related family study net_mig outflow out_work out_family out_study{
gen ihs_`var' = asinh(`var')
}

//(panel 1)

reg ihs_all_reasons treat_post i.id i.time, vce(robust)
reg ihs_work_related treat_post i.id i.time, vce(robust)
reg ihs_family treat_post i.id i.time, vce(robust)
reg ihs_study treat_post i.id i.time, vce(robust)

//(panel 2)

reg ihs_outflow treat_post i.id i.time, vce(robust)
reg ihs_out_work treat_post i.id i.time, vce(robust)
reg ihs_out_family treat_post i.id i.time, vce(robust)
reg ihs_out_study treat_post i.id i.time, vce(robust)

*****************************************************************************************************************************************************************
//Table B.6
*****************************************************************************************************************************************************************

reg ihs_net_mig treat_post i.id i.time, vce(robust)
reg ihs_net_mig EU2_post i.id i.time, vce(robust)
reg ihs_net_mig EU3_post i.id i.time, vce(robust)


*****************************************************************************************************************************************************************
//TABLE C8
*****************************************************************************************************************************************************************

reg l_all_reasons EU EU#ib2016.year i.id i.time, vce(robust)
reg l_work_related EU EU#ib2016.year i.id i.time, vce(robust)
reg l_family EU EU#ib2016.year i.id i.time, vce(robust)
reg l_study EU EU#ib2016.year i.id i.time, vce(robust)

reg l_all_reasons EU2 EU2#ib2016.year i.id i.time, vce(robust)
reg l_work_related EU2 EU2#ib2016.year i.id i.time, vce(robust)
reg l_family EU2 EU2#ib2016.year i.id i.time, vce(robust)
reg l_study EU2 EU2#ib2016.year i.id i.time, vce(robust)

reg l_all_reasons EU3 EU3#ib2016.year i.id i.time, vce(robust)
reg l_work_related EU3 EU3#ib2016.year i.id i.time, vce(robust)
reg l_family EU3 EU3#ib2016.year i.id i.time, vce(robust)
reg l_study EU3 EU3#ib2016.year i.id i.time, vce(robust)

*****************************************************************************************************************************************************************
//TABLE C10
*****************************************************************************************************************************************************************

reg l_all_reasons treat_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_work_related treat_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_family treat_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_study treat_post i.id i.time if year < 2019 & time > 6, vce(robust)

gen EU2_post = EU2*post_ref
label variable EU2_post "EU14*post_ref"

//European Union EU15
reg l_all_reasons EU2_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_work_related EU2_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_family EU2_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_study EU2_post i.id i.time if year < 2019 & time > 6, vce(robust)

gen EU3_post = EU3*post_ref
label variable EU3_post "EU_new*post_ref"

//European Union new
reg l_all_reasons EU3_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_work_related EU3_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_family EU3_post i.id i.time if year < 2019 & time > 6, vce(robust)
reg l_study EU3_post i.id i.time if year < 2019 & time > 6, vce(robust)

*****************************************************************************************************************************************************************
//TABLE C9
*****************************************************************************************************************************************************************

reg l_all_reasons treat_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_work_related treat_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_family treat_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_study treat_post i.id i.time if year < 2018 & time > 10, vce(robust)

//European Union EU15
reg l_all_reasons EU2_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_work_related EU2_post i.id i.time year < 2018 & time > 10, vce(robust)
reg l_family EU2_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_study EU2_post i.id i.time if year < 2018 & time > 10, vce(robust)


//European Union new
reg l_all_reasons EU3_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_work_related EU3_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_family EU3_post i.id i.time if year < 2018 & time > 10, vce(robust)
reg l_study EU3_post i.id i.time if year < 2018 & time > 10, vce(robust)

*****************************************************************************************************************************************************************
//TABLE H23
*****************************************************************************************************************************************************************

reg l_all_reasons treat_post i.id i.time if id != 11, vce(robust)
reg l_work_related treat_post i.id i.time if id != 11, vce(robust)
reg l_family treat_post i.id i.time if id != 11, vce(robust)
reg l_study treat_post i.id i.time if id != 11, vce(robust)

reg l_all_reasons EU2_post i.id i.time if id != 11, vce(robust)
reg l_work_related EU2_post i.id i.time if id != 11, vce(robust)
reg l_family EU2_post i.id i.time if id != 11, vce(robust)
reg l_study EU2_post i.id i.time if id != 11, vce(robust)

reg l_all_reasons EU3_post i.id i.time if id != 11, vce(robust)
reg l_work_related EU3_post i.id i.time if id != 11, vce(robust)
reg l_family EU3_post i.id i.time if id != 11, vce(robust)
reg l_study EU3_post i.id i.time if id != 11, vce(robust)

*****************************************************************************************************************************************************************
//TABLE H24
*****************************************************************************************************************************************************************

reg l_outflow treat_post i.id i.time if id != 11, vce(robust)
reg l_out_work treat_post i.id i.time if id != 11, vce(robust)
reg l_out_family treat_post i.id i.time if id != 11, vce(robust)
reg l_out_study treat_post i.id i.time if id != 11, vce(robust)

reg l_outflow EU2_post i.id i.time if id != 11, vce(robust)
reg l_out_work EU2_post i.id i.time if id != 11, vce(robust)
reg l_out_family EU2_post i.id i.time if id != 11, vce(robust)
reg l_out_study EU2_post i.id i.time if id != 11, vce(robust)

reg l_outflow EU3_post i.id i.time if id != 11, vce(robust)
reg l_out_work EU3_post i.id i.time if id != 11, vce(robust)
reg l_out_family EU3_post i.id i.time if id != 11, vce(robust)
reg l_out_study EU3_post i.id i.time if id != 11, vce(robust)


*****************************************************************************************************************************************************************
//TABLE H25
*****************************************************************************************************************************************************************

reg l_net_mig treat_post i.id i.time if id != 11, vce(robust)
reg l_net_mig EU2_post i.id i.time if id != 11, vce(robust)
reg l_net_mig EU3_post i.id i.time if id != 11, vce(robust)


****************************************************************************************************************************************************************
// FIGURE 2
****************************************************************************************************************************************************************

labmask time, values(Quarter)

drop if date < 19329
replace time = time - 4

xtreg l_all_reasons EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


xtreg l_work_related EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


xtreg l_family EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


xtreg l_study EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


****************************************************************************************************************************************************************
// FIGURE 5
****************************************************************************************************************************************************************

xtreg l_outflow EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


xtreg l_out_work EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


xtreg l_out_family EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


xtreg l_out_study EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))

****************************************************************************************************************************************************************
// FIGURE 6(b)
****************************************************************************************************************************************************************

xtreg l_net_mig EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) ytitle(Difference (log)) rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(2 = "Jun2013" 6 = "Jun2014" 10 = "Jun2015"  18 = "Jun2017" 22 = "Jun2018" 26 = "Jun2019" , angle(45) labsize(small))


*****************************************************************************************************************************************************************
//Descriptive Tables preparation
*****************************************************************************************************************************************************************

collapse (sum) all_reasons work_related family study outflow out_work out_family out_study all_reasons_0 all_reasons_fix work_0 work_fix non_work_0 non_work_fix, by(date time EU)
 
drop if date < 19329
xtset EU date, daily

gen post_ref = 1
replace post_ref = 0 if date < 20607


*****************************************************************************************************************************************************************//TABLE 1
*****************************************************************************************************************************************************************


//Descriptive table EU (total, pre and post referendum)

estpost sum all_reasons work_related family study if EU == 1
est store a
estpost sum all_reasons work_related family study if EU == 1 & post_ref == 0
est store b
estpost sum all_reasons work_related family study if EU == 1 & post_ref == 1
est store c

esttab a b c 

//Descriptive table non-EU (total, pre and post referendum)

estpost sum all_reasons work_related family study if EU == 0
est store a
estpost sum all_reasons work_related family study if EU == 0 & post_ref == 0
est store b
estpost sum all_reasons work_related family study if EU == 0 & post_ref == 1
est store c

esttab a b c 

//T-test

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1


foreach var in all_reasons work_related family study{
estpost ttest `var' if EU == 1, by(pre_ref)
est store a
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab a b 
}

*****************************************************************************************************************************************************************//TABLE 3
*****************************************************************************************************************************************************************

//Descriptive table EU (total, pre and post referendum)

estpost sum outflow out_work out_family out_study if EU == 1
est store a
estpost sum outflow out_work out_family out_study if EU == 1 & post_ref == 0
est store b
estpost sum outflow out_work out_family out_study if EU == 1 & post_ref == 1
est store c

esttab a b c 

//Descriptive table non-EU (total, pre and post referendum)

estpost sum outflow out_work out_family out_study if EU == 0
est store a
estpost sum outflow out_work out_family out_study if EU == 0 & post_ref == 0
est store b
estpost sum outflow out_work out_family out_study if EU == 0 & post_ref == 1
est store c

esttab a b c 

//T-test


foreach var in outflow out_work out_family out_study{
estpost ttest `var' if EU == 1, by(pre_ref)
est store a
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab a b 
}

*****************************************************************************************************************************************************************//TABLE 4
*****************************************************************************************************************************************************************

gen net_mig = all_reasons-outflow

estpost sum net_mig if EU == 1
est store a
estpost sum net_mig if EU == 1 & post_ref == 0
est store b
estpost sum net_mig if EU == 1 & post_ref == 1
est store c

esttab a b c 

estpost sum net_mig if EU == 0
est store a
estpost sum net_mig if EU == 0 & post_ref == 0
est store b
estpost sum net_mig if EU == 0 & post_ref == 1
est store c

esttab a b c 

estpost ttest net_mig if EU == 1, by(pre_ref)
est store a
estpost ttest net_mig if EU == 0, by(pre_ref)
est store b
esttab a b 

*****************************************************************************************************************************************************************//TABLE 16
*****************************************************************************************************************************************************************

//Scenario 1

//Descriptive table non-EU (total, pre and post referendum)

estpost sum all_reasons_0 work_0 non_work_0 if EU == 0
est store a
estpost sum all_reasons_0 work_0 non_work_0 if EU == 0 & post_ref == 0
est store b
estpost sum all_reasons_0 work_0 non_work_0 if EU == 0 & post_ref == 1
est store c

esttab a b c 

//T-test

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1


foreach var in all_reasons_0 work_0 non_work_0{
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab b 
}

//Scenario 2

//Descriptive table non-EU (total, pre and post referendum)

estpost sum all_reasons_fix work_fix non_work_fix if EU == 0
est store a
estpost sum all_reasons_fix work_fix non_work_fix if EU == 0 & post_ref == 0
est store b
estpost sum all_reasons_fix work_fix non_work_fix if EU == 0 & post_ref == 1
est store c

esttab a b c 

//T-test

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1


foreach var in all_reasons_fix work_fix non_work_fix{
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab b 
}


*****************************************************************************************************************************************************************
// FIGURE 1
*****************************************************************************************************************************************************************

foreach var in all_reasons work_related family study{
gen l_`var' = log(1+`var')
}


twoway (line l_all_reasons date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_all_reasons date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

twoway (line l_work_related date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_work_related date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

twoway (line l_family date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_family date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

twoway (line l_study date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_study date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

*****************************************************************************************************************************************************************
// FIGURE D2
*****************************************************************************************************************************************************************

gen non_work = family+study

twoway (line work_related date if EU == 0, sort lcolor(blue) lwidth(medthick)) ///
(line non_work date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "Work" 2 "Non-work")) ytitle(Number of migrants)

*****************************************************************************************************************************************************************
// FIGURE 4
*****************************************************************************************************************************************************************

foreach var in outflow out_work out_family out_study{
gen l_`var' = log(1+`var')
}


twoway (line l_outflow date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_outflow date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

twoway (line l_out_work date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_out_work date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

twoway (line l_out_family date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_out_family date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

twoway (line l_out_study date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_out_study date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

*****************************************************************************************************************************************************************
// FIGURE 6 (a)
*****************************************************************************************************************************************************************

gen l_net_mig = log(1+net_mig)


twoway (line l_net_mig date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_net_mig date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) legend(order(1 "EU" 2 "Non-EU")) ytitle(Number of migrants (log))

*****************************************************************************************************************************************************************
//Descriptive Tables preparation (Appendix H)
*****************************************************************************************************************************************************************

use "$dir_data/Data/LTIM.dta", clear 

drop if id == 11
collapse (sum) all_reasons work_related family study out_work out_family out_study, by(date time EU)
 
drop if date < 19329
xtset EU date, daily

gen post_ref = 1
replace post_ref = 0 if date < 20607

*****************************************************************************************************************************************************************
//TABLE H22
*****************************************************************************************************************************************************************

estpost sum all_reasons work_related family study if EU == 1
est store a
estpost sum all_reasons work_related family study if EU == 1 & post_ref == 0
est store b
estpost sum all_reasons work_related family study if EU == 1 & post_ref == 1
est store c

esttab a b c 

estpost sum all_reasons work_related family study if EU == 0
est store a
estpost sum all_reasons work_related family study if EU == 0 & post_ref == 0
est store b
estpost sum all_reasons work_related family study if EU == 0 & post_ref == 1
est store c

esttab a b c 

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1


foreach var in all_reasons work_related family study{
estpost ttest `var' if EU == 1, by(pre_ref)
est store a
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab a b 
}


estpost sum outflow out_work out_family out_study if EU == 1
est store a
estpost sum outflow out_work out_family out_study if EU == 1 & post_ref == 0
est store b
estpost sum outflow out_work out_family out_study if EU == 1 & post_ref == 1
est store c

esttab a b c 

estpost sum outflow out_work out_family out_study if EU == 0
est store a
estpost sum outflow out_work out_family out_study if EU == 0 & post_ref == 0
est store b
estpost sum outflow out_work out_family out_study if EU == 0 & post_ref == 1
est store c

esttab a b c 


foreach var in outflow out_work out_family out_study{
estpost ttest `var' if EU == 1, by(pre_ref)
est store a
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab a b 
}


gen net_mig = all_reasons-outflow

estpost sum net_mig if EU == 1
est store a
estpost sum net_mig if EU == 1 & post_ref == 0
est store b
estpost sum net_mig if EU == 1 & post_ref == 1
est store c

esttab a b c 

estpost sum net_mig if EU == 0
est store a
estpost sum net_mig if EU == 0 & post_ref == 0
est store b
estpost sum net_mig if EU == 0 & post_ref == 1
est store c

esttab a b c 

estpost ttest net_mig if EU == 1, by(pre_ref)
est store a
estpost ttest net_mig if EU == 0, by(pre_ref)
est store b
esttab a b 


