*******************************************************
********************** DATA PATH **********************
*******************************************************

*** insert below the path to the folder where you copy the replication archive
*** in this path insert also the following files from the Data folder

global dir_data = 	"  "

use "$dir_data\Data\OECD.dta", clear

reg l_value EU post_ref treat_post i.time if dest != "UK" & year != 2016, vce(robust)
reg l_value treat_post i.time i.n_ori if dest != "UK" & year != 2016, vce(robust)
reg l_value treat_post i.time i.n_ori i.n_des if dest != "UK" & year != 2016, vce(robust)
reg l_value treat_post l.log_GDP i.time i.n_ori i.n_des if dest != "UK" & year != 2016, vce(robust)
reg l_value treat_post l.log_GDP l.unemp i.time i.n_ori i.n_des if dest != "UK" & year != 2016, vce(robust)

reg l_value EU UK post_ref treat_post post_uk i.time if year != 2016, vce(robust)
reg l_value UK treat_post post_uk i.time i.n_ori if year != 2016, vce(robust) 
reg l_value UK treat_post post_uk i.time i.n_ori i.n_des if year != 2016, vce(robust) 
reg l_value UK treat_post post_uk l.log_GDP i.time i.n_ori n_des if year != 2016, vce(robust)
reg l_value UK treat_post post_uk l.log_GDP l.unemp i.time i.n_ori n_des if year != 2016, vce(robust)

//Parallel trends

reg l_value EU#ib2016.year if dest != "UK" & year != 2012 , coeflegend
levelsof year, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) ytitle("Difference (log)") xline(3.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Year) title("EU") coeflabels(1 = "2014" 2 = "2015" 3 = "2017", angle(45) labsize(small))

//Descriptive statistics

collapse (sum) value, by(year EU UK)

gen post_ref = 1
replace post_ref = 0 if year < 2016

replace value = . if year == 2012
drop if year == 2016
//UK
estpost sum value if EU == 1 & UK == 1
est store a
estpost sum value if EU == 1 & UK == 1 & post_ref == 0
est store b
estpost sum value if EU == 1 & UK == 1 & post_ref == 1
est store c

esttab a b c 

estpost sum value if EU == 0 & UK == 1
est store a
estpost sum value if EU == 0 & UK == 1 & post_ref == 0
est store b
estpost sum value if EU == 0 & UK == 1 & post_ref == 1
est store c

esttab a b c 

//EU
estpost sum value if EU == 1 & UK == 0
est store a
estpost sum value if EU == 1 & UK == 0 & post_ref == 0
est store b
estpost sum value if EU == 1 & UK == 0 & post_ref == 1
est store c

esttab a b c 

estpost sum value if EU == 0 & UK == 0
est store a
estpost sum value if EU == 0 & UK == 0 & post_ref == 0
est store b
estpost sum value if EU == 0 & UK == 0 & post_ref == 1
est store c

esttab a b c 

//T-test

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1

estpost ttest value if EU == 1 & UK == 1, by(pre_ref)
est store a
estpost ttest value if EU == 0 & UK == 1, by(pre_ref)
est store b
esttab a b 

estpost ttest value if EU == 1 & UK == 0, by(pre_ref)
est store a
estpost ttest value if EU == 0 & UK == 0, by(pre_ref)
est store b
esttab a b 

//Diagrams

use "$dir_data\Data\OECD.dta", clear

drop if UK == 1

collapse (sum) value, by(year EU)

tab year
gen l_value = ln(1+value)

drop if year == 2012
twoway (line l_value year if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(line l_value year if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(2016, lwidth(medthick) lcolor(cranberry)) title(EU) legend(order(1 "EU" 2 "Non-EU")) ///
xtitle(Year) ytitle(Inflows) xlabel(2013(1)2019)

