*******************************************************
********************** DATA PATH **********************
*******************************************************

*** insert below the path to the folder where you copy the replication archive
*** in this path insert also the following files from the Data folder

global dir_data = 	"  "

use "$dir_data\Data\UKLFS_cob.dta", clear

foreach var in nweight hig_qual low_qual hig_qual_alt low_qual_alt female male young old high_pro low_pro london south_east region_rest manufactury construction hospitality finance admin sec_rest{
gen l_`var' = ln(1+`var')

}


gen EU15 = 0
replace EU15 = 1 if NATOX7 == 3
replace EU15 = . if EU == 1 & NATOX7 != 3

gen EU_new = 0
replace EU_new = 1 if NATOX7 > 3 & NATOX7 < 7
replace EU_new = . if EU == 1 & NATOX7 == 3

gen treat_EU15 = EU15*post_ref
label variable treat_EU15 "EU15*post_ref"

gen treat_EUnew = EU_new*post_ref
label variable treat_EUnew "EU_new*post_ref"

*********************************************************************************************************************************************************************// TABLE 7
*********************************************************************************************************************************************************************
reg l_nweight treat_post i.NATOX7 i.time, vce(robust)
reg l_nweight treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_nweight treat_EUnew i.NATOX7 i.time, vce(robust)

*****************************************************************************************************************************************************************
**//TABLE 10
*****************************************************************************************************************************************************************

// Panel 2
reg l_nweight EU post_ref l4.log_GDP l4.Unemployment i.NATOX7 if EU == 1, vce(robust)

// Panel 7
reg l_nweight EU post_ref l4.log_GDP l4.Unemployment i.NATOX7 if EU == 0, vce(robust)

*****************************************************************************************************************************************************************
**//TABLE 14
*****************************************************************************************************************************************************************
gen work = high_pro+low_pro
replace work = nweight-work if EU == 0
replace work = 0 if work == .

gen l_work = ln(1+work)

replace l_work = . if time < 5

egen id = group(Subgroup)

reg l_work treat_post i.NATOX7 i.time, vce(robust)
reg l_work treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_work treat_EUnew i.NATOX7 i.time, vce(robust)

*******************************************************************************************************************************************************************//FIGURE 3 (b)

drop if date < 19329
replace time = time - 4


xtreg l_nweight EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) title("Total") rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(1 = "Mar2013" 2 = "Jun2013" 3 = "Sep2013" ///
4 = "Dec2013" 5 = "Mar2014" 6 = "Jun2014" 7 = "Sep2014" 8 = "Dec2014" 9 = "Mar2015" 10 = "Jun2015" 11 = "Sep2015" 12 = "Dec2015" 13 = "Mar2016" 15 = "Sep2016" 16 = "Dec2016" ///
17 = "Mar2017" 18 = "Jun2017" 19 = "Sep2017" 20 = "Dec2017" 21 = "Mar2018" 22 = "Jun2018" 23 = "Sep2018" 24 = "Dec2018" 25 = "Mar2019" 26 = "Jun2019" 27 = "Sep2019" 28 = "Dec2019" , angle(45) labsize(small))

*******************************************************************************************************************************************************************//FIGURE 7 (b)

drop if date < 19329
replace time = time - 4


xtreg l_work EU##ib14.time , coeflegend
levelsof time, local(levels)

foreach l of local levels {
    local mylist "`mylist' `l'.time"
}

coefplot, vertical drop(_cons 1.EU `mylist') yline(0) xline(13.5, lpattern (dash) lcolor (gray)) recast(connected) xtitle(Quarter) title("Total") rename(^1.EU#([0-9]+).time$ = \1, regex) coeflabels(1 = "Mar2013" 2 = "Jun2013" 3 = "Sep2013" ///
4 = "Dec2013" 5 = "Mar2014" 6 = "Jun2014" 7 = "Sep2014" 8 = "Dec2014" 9 = "Mar2015" 10 = "Jun2015" 11 = "Sep2015" 12 = "Dec2015" 13 = "Mar2016" 15 = "Sep2016" 16 = "Dec2016" ///
17 = "Mar2017" 18 = "Jun2017" 19 = "Sep2017" 20 = "Dec2017" 21 = "Mar2018" 22 = "Jun2018" 23 = "Sep2018" 24 = "Dec2018" 25 = "Mar2019" 26 = "Jun2019" 27 = "Sep2019" 28 = "Dec2019" , angle(45) labsize(small))

*******************************************************************************************************************************************************************//TABLE 2

collapse (sum) nweight hig_qual low_qual female male young old high_pro low_pro work, by(EU time)

gen date = date(time, "MY")
labmask date, values(time)

gen post_ref = 1
replace post_ref = 0 if date < 20607


foreach var in nweight hig_qual low_qual female male young old{

estpost sum `var' if EU == 1
est store a
estpost sum `var' if EU == 1 & post_ref == 0
est store b
estpost sum `var' if EU == 1 & post_ref == 1
est store c

esttab a b c 

estpost sum `var' if EU == 0
est store a
estpost sum `var' if EU == 0 & post_ref == 0
est store b
estpost sum `var' if EU == 0 & post_ref == 1
est store c

esttab a b c 
}

gen pre_ref = 1
replace pre_ref = 0 if post_ref == 1


foreach var in nweight female male hig_qual low_qual young old {
estpost ttest `var' if EU == 1, by(pre_ref)
est store a
estpost ttest `var' if EU == 0, by(pre_ref)
est store b
esttab a b using 
}

*******************************************************************************************************************************************************************//FIGURE 3 (a)
*****************************************************************************************************************************************************************
gen l_nweight = ln(1+nweight)

twoway (lowess l_nweight date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(lowess l_nweight date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) title("EU vs non-EU") legend(order(1 "EU" 2 "Non-EU"))

*******************************************************************************************************************************************************************//FIGURE 7 (a)
*****************************************************************************************************************************************************************
gen l_work = ln(1+work)

twoway (lowess l_work date if EU == 1, sort lcolor(blue) lwidth(medthick)) ///
(lowess l_work date if EU == 0, sort lcolor(forest_green) lwidth(medthick)), /// 
xline(20607, lwidth(medthick) lcolor(cranberry)) title("EU vs non-EU") legend(order(1 "EU" 2 "Non-EU"))


*******************************************************************************************************************************************************************//FIGURE 8
*****************************************************************************************************************************************************************
import excel "$dir_data\DiDeffects.xlsx", firstrow clear

graph bar (mean) DID if ID < 5, over( EU ) over(ID) blabel(bar, format(%4.0f)) intensity(25) ytitle("DiD effect")
graph bar (mean) DID if ID > 4 & ID < 9, over( EU ) over(Variable) blabel(bar, format(%4.0f)) intensity(25) ytitle("DiD effect")
graph bar (mean) DID if ID > 8, over( EU ) over(ID) blabel(bar, format(%4.0f)) intensity(25) ytitle("DiD effect")


*****************************************************************************************************************************************************************
use "$dir_data\Data\UKLFS_cob.dta", clear

foreach var in nweight hig_qual low_qual hig_qual_alt low_qual_alt female male young old high_pro low_pro london south_east region_rest manufactury construction hospitality finance admin sec_rest{
gen l_`var' = ln(1+`var')

}


gen EU15 = 0
replace EU15 = 1 if NATOX7 == 3
replace EU15 = . if EU == 1 & NATOX7 != 3

gen EU_new = 0
replace EU_new = 1 if NATOX7 > 3 & NATOX7 < 7
replace EU_new = . if EU == 1 & NATOX7 == 3

gen treat_EU15 = EU15*post_ref
label variable treat_EU15 "EU15*post_ref"

gen treat_EUnew = EU_new*post_ref
label variable treat_EUnew "EU_new*post_ref"

***********************************************************************************************************************************************************************//TABLE B7
*******************************************************************************************************************************************************************
gen ihs_nweight = asinh(nweight)

reg ihs_nweight treat_post i.NATOX7 i.time, vce(robust)
reg ihs_nweight treat_EU15 i.NATOX7 i.time, vce(robust)
reg ihs_nweight treat_EUnew i.NATOX7 i.time, vce(robust)

*********************************************************************************************************************************************************************//TABLE F12
*******************************************************************************************************************************************************************

reg l_nweight treat_post i.NATOX7 i.time, vce(robust)
reg l_hig_qual treat_post i.NATOX7 i.time, vce(robust)
reg l_low_qual treat_post i.NATOX7 i.time, vce(robust)
reg l_female treat_post i.NATOX7 i.time, vce(robust)
reg l_male treat_post i.NATOX7 i.time, vce(robust)
reg l_young treat_post i.NATOX7 i.time, vce(robust)
reg l_old treat_post i.NATOX7 i.time, vce(robust)
reg l_london treat_post i.NATOX7 i.time, vce(robust)
reg l_south_east treat_post i.NATOX7 i.time, vce(robust)
reg l_region_rest treat_post i.NATOX7 i.time, vce(robust)

reg l_nweight treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_hig_qual treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_low_qual treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_female treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_male treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_young treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_old treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_london treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_south_east treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_region_rest treat_EU15 i.NATOX7 i.time, vce(robust)

reg l_nweight treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_hig_qual treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_low_qual treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_female treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_male treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_young treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_old treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_london treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_south_east treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_region_rest treat_EUnew i.NATOX7 i.time, vce(robust)

*********************************************************************************************************************************************************************//TABLE F13
*****************************************************************************************************************************************************************

reg l_high_pro treat_post i.NATOX7 i.time, vce(robust)
reg l_low_pro treat_post i.NATOX7 i.time, vce(robust)
reg l_manufactury treat_post i.NATOX7 i.time, vce(robust)
reg l_construction treat_post i.NATOX7 i.time, vce(robust)
reg l_hospitality treat_post i.NATOX7 i.time, vce(robust)
reg l_finance treat_post i.NATOX7 i.time, vce(robust)
reg l_admin treat_post i.NATOX7 i.time, vce(robust)
reg l_sec_rest treat_post i.NATOX7 i.time, vce(robust)

reg l_high_pro treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_low_pro treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_manufactury treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_construction treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_hospitality treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_finance treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_admin treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_sec_rest treat_EU15 i.NATOX7 i.time, vce(robust)

reg l_high_pro treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_low_pro treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_manufactury treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_construction treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_hospitality treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_finance treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_admin treat_EUnew i.NATOX7 i.time, vce(robust)
reg l_sec_rest treat_EUnew i.NATOX7 i.time, vce(robust)

***********************************************************************************************************************************************************************//TABLE H26
*******************************************************************************************************************************************************************
gen ihs_nweight = asinh(nweight)

reg l_nweight treat_post i.NATOX7 i.time if Subgroup != "Other Europe", vce(robust)
reg l_nweight treat_EU15 i.NATOX7 i.time Subgroup != "Other Europe", vce(robust)
reg l_nweight treat_EUnew i.NATOX7 i.time Subgroup != "Other Europe", vce(robust)


*********************************************************************************************************************************************************************//TABLE I28
*****************************************************************************************************************************************************************

drop l_nweight - l_old

foreach var in nweight PWT18  hig_qual low_qual female male young old ///
w_hig_qual w_low_qual w_female w_male w_young w_old {
replace `var' = . if `var' == 0
}

foreach var in nweight hig_qual low_qual female male young old{
gen l_`var' = ln(1+`var')
}

eststo a: reg l_nweight treat_post i.NATOX7 i.year, vce(robust)
eststo b: reg l_hig_qual treat_post i.NATOX7 i.year, vce(robust)
eststo c: reg l_low_qual treat_post i.NATOX7 i.year, vce(robust)
eststo d: reg l_female treat_post i.NATOX7 i.year, vce(robust)
eststo e: reg l_male treat_post i.NATOX7 i.year, vce(robust)
eststo f: reg l_young treat_post i.NATOX7 i.year, vce(robust)
eststo g: reg l_old treat_post i.NATOX7 i.year, vce(robust)


*********************************************************************************************************************************************************************//TABLE I29
*****************************************************************************************************************************************************************

**To replicate this Table follow the instructions at lines 979-986 of the UKLFS_preparation file
**Open the alternative file and run the following:

gen l_nweight = ln(1+nweight)

reg l_nweight treat_post i.NATOX7 i.time, vce(robust)
reg l_nweight treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_nweight treat_EUnew i.NATOX7 i.time, vce(robust)


*********************************************************************************************************************************************************************//TABLE I27
*****************************************************************************************************************************************************************

**To replicate this Table follow the instructions at lines 26-27 of the UKLFS_preparation file
**Open the alternative file and run the following:

foreach var in nweight hig_qual low_qual {

gen l_`var' = ln(1+`var')
}

reg l_nweight treat_post i.NATOX7 i.time, vce(robust)
reg l_hig_qual treat_post i.NATOX7 i.year, vce(robust)
reg l_low_qual treat_post i.NATOX7 i.year, vce(robust)
reg l_nweight treat_EU15 i.NATOX7 i.time, vce(robust)
reg l_nweight treat_EUnew i.NATOX7 i.time, vce(robust)


*********************************************************************************************************************************************************************//TABLE F19
*****************************************************************************************************************************************************************

keep Subgroup Quarter NATOX7 l_hig_qual l_low_qual post_ref treat_post EU EU15 EU_new treat_EU15 treat_EUnew

rename l_hig_qual ed1
rename l_low_qual ed0

egen id = group(Subgroup Quarter)
drop if id == .
reshape long ed, i(id) j(education)

gen treat_post_low = treat_post*education
gen treat_post_low15 = treat_EU15*education
gen treat_post_lownew = treat_EUnew*education

label variable education "High_ed"
label variable treat_post_low "EU*post_ref*high_ed"
label variable treat_post_low15 "EU14*post_ref*high_ed"
label variable treat_post_lownew "EU_new*post_ref*high_ed"

egen time = group(Quarter)

reg ed education EU post_ref treat_post treat_post_low i.NATOX7 i.time, vce(robust)
reg ed education EU15 post_ref treat_EU15 treat_post_low15 i.NATOX7 i.time, vce(robust)
reg ed education EU_new post_ref treat_EUnew treat_post_lownew i.NATOX7 i.time, vce(robust)
