*******************************************************
********************** DATA PATH **********************
*******************************************************

*** insert below the path to the folder where you copy the replication archive
*** in this path also download the UKLFS data from https://beta.ukdataservice.ac.uk

global dir_data = 	"  "

//In this do file I am re-building up the database from the LFS (EUL) to run the placebo tests
//For the replication it is necessary to combine UK LFS (EUL) quarterly data from 2010 to 2016
//All data should be accessed through https://beta.ukdataservice.ac.uk
//The UKLFS files are named lfsp_(quarter)(year)_eul.dta. For instance, quarter 4 of 2012 is named as follows: lfsp_q412_eul.dta
//To run the following loops it is necessary to rename the files as follows: year_q(quarter).dta. For instance, quarter 3 of 2010: 2010_q3

forval i = 3/4{
use "$dir_data\2010_q`i'.dta", clear
keep if NATOX7 != 926
keep if THISWV == 1
keep CAMEMT CAMEYR CAMEYR2 SEX AGE NATOX7

keep if CAMEMT > 0
replace CAMEYR2 = 0 if CAMEYR2 == -9
replace CAMEYR = CAMEYR2 if CAMEYR2 > CAMEYR
keep if CAMEYR > 2009
drop CAMEYR2


merge m:1 NATOX7 using "$dir_data\Data\codebook.dta", keepusing(COUNTRY)generate(_merge1)
drop if _merge1 != 3
merge m:1 COUNTRY using "$dir_data\Data\nationalities.dta", keepusing(Subgroup) generate(_merge2)
drop if _merge2 == 2

gen inflow = 1
gen year=2010
gen quarter =`i'
save "$dir_data\2010q`i'.dta", replace
}

append using "$dir_data\2010q3.dta"
drop if Subgroup == "" 
save "$dir_data\2010_tot.dta", replace


forval i = 1/4{
use "$dir_data\2011_q`i'.dta", clear
keep if NATOX7 != 926
keep if THISWV == 1
keep CAMEMT CAMEYR CAMEYR2 SEX AGE NATOX7

keep if CAMEMT > 0
replace CAMEYR2 = 0 if CAMEYR2 == -9
replace CAMEYR = CAMEYR2 if CAMEYR2 > CAMEYR
keep if CAMEYR > 2009
drop CAMEYR2

merge m:1 NATOX7 using "$dir_data\Data\codebook.dta", keepusing(COUNTRY)generate(_merge1)
drop if _merge1 != 3
merge m:1 COUNTRY using "$dir_data\Data\nationalities.dta", keepusing(Subgroup) generate(_merge2)
drop if _merge2 == 2

gen inflow = 1
gen year=2011
gen quarter =`i'
save "$dir_data\2011q`i'.dta", replace
}

append using "$dir_data\2011q1.dta" "$dir_data\2011q2.dta" "$dir_data\2011q3.dta"
drop if Subgroup == "" 
save "$dir_data\2011_tot.dta", replace


forval i = 1/3{
use "$dir_data\2012_q`i'.dta", clear
keep if NATOX7 != 926
keep if THISWV == 1
keep CAMEMT CAMEYR CAMEYR2 SEX AGE NATOX7

keep if CAMEMT > 0
replace CAMEYR2 = 0 if CAMEYR2 == -9
replace CAMEYR = CAMEYR2 if CAMEYR2 > CAMEYR
keep if CAMEYR > 2009
drop CAMEYR2

merge m:1 NATOX7 using "$dir_data\Data\codebook2013.dta", keepusing(COUNTRY)generate(_merge1)
drop if _merge1 != 3
merge m:1 COUNTRY using "$dir_data\Data\nationalities.dta", keepusing(Subgroup) generate(_merge2)
drop if _merge2 == 2

gen inflow = 1
gen year=2012
gen quarter =`i'
save "$dir_data\2012q`i'.dta", replace
}

append using "$dir_data\2012q1.dta" "$dir_data\2012q2.dta" 
save "$dir_data\2012_tot.dta", replace

append using "$dir_data\2010_tot.dta" "$dir_data\2011_tot.dta"


keep if CAMEYR > 2009

gen quarter_arrival = 1
replace quarter_arrival = 2 if CAMEMT > 3 & CAMEMT < 7
replace quarter_arrival = 3 if CAMEMT > 6 & CAMEMT < 10
replace quarter_arrival = 4 if CAMEMT > 9

gen month = "Mar" 
replace month = "Jun" if quarter_arrival == 2
replace month = "Sep" if quarter_arrival == 3
replace month = "Dec" if quarter_arrival == 4

tostring CAMEYR, gen(cameyr)

gen time = month+cameyr

drop if time == "Dec."
drop if Subgroup == ""
drop if time == "Mar2010"

collapse (sum) inflow, by(Subgroup time)
save "$dir_data\placebo_inflows.dta", replace


use "$dir_data\Data\UKLFS_cob.dta", clear

append using "$dir_data\placebo_inflows.dta"

replace nweight = inflow if nweight == .

insobs 4, before(1)
replace Subgroup = "European Union EU15" in 1
replace Subgroup = "European Union EU15" in 2
replace Subgroup = "European Union EU15" in 3
replace Subgroup = "European Union EU15" in 4

replace time = "Jun2009" in 3
replace time = "Sep2009" in 2
replace time = "Mar2010" in 1
replace time = "Dec2009" in 4

fillin Subgroup time

gen date = date(time, "MY")

labmask date, values(time)

drop if date > 20514

gen EU = 0
replace EU = 1 if Subgroup == "European Union EU15" | Subgroup == "European Union EU8" ///
| Subgroup == "European Union EU2" | Subgroup == "European Union Other"


tab Subgroup if EU == 1
tab Subgroup if EU == 0

label define EU 0 "Non EU" 1 "EU" 

replace nweight = 0 if _fillin == 1 & date > 18232
gen l_inflow = ln(1+nweight)
gen post_ref = 0
replace post_ref = 1 if date > 19418

gen treat_post = EU*post_ref
gen year = substr(Quarter, 4,4)
destring year, replace

egen time_new = group(date)
egen id = group(Subgroup)

drop if Subgroup == ""

xtset id time_new

set more off, permanently

drop post_ref1
drop if time < 5
gen post_ref1 = 0
replace post_ref1 = 1 if time > 16
gen treat_post1 = post_ref1*EU

save "$dir_data\UKLFS_placebo.dta", replace




