## Installation

# Install remotes package if not installed
install.packages("remotes") 

# Turn off warning-error-conversion, because the tiniest warning stops installation
Sys.setenv("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "true")

# install from github
remotes::install_github("asheshrambachan/HonestDiD")

#Install here, dplyr, did, haven, ggplot2 packages from CRAN if not yet installed
#install.packages(c("here", "dplyr", "did", "haven", "ggplot2", "fixest"))

install.packages("Rglpk")
library(here)
library(dplyr)
library(did)
library(haven)
library(ggplot2)
library(fixest)
library(HonestDiD)


#### LTIM work inflows

vec2 <-c(-0.378,-0.231,-0.207,-0.274,-0.042,-0.146, -0.203, -0.063, -0.217, -0.239, -0.096, -0.109, -0.143, -0.777, -1.130)

work_matrix2 <- read_excel("~/work_matrix.xlsx")
results4 <-data.matrix(work_matrix2)

delta_rm_results <- 
  HonestDiD::createSensitivityResults_relativeMagnitudes(
    betahat = vec2, #coefficients
    sigma = results4, #covariance matrix
    numPrePeriods = 13, #num. of pre-treatment coefs
    numPostPeriods =4, #num. of post-treatment coefs
    Mbarvec = seq(0.5,2,by=0.5) #values of Mbar
  )

delta_rm_results

originalResults <- HonestDiD::constructOriginalCS(betahat = vec2,
                                                  sigma = results4,
                                                  numPrePeriods = 13,
                                                  numPostPeriods = 4)

HonestDiD::createSensitivityPlot_relativeMagnitudes(delta_rm_results, originalResults)


delta_sd_results <- 
  HonestDiD::createSensitivityResults(betahat = vec2,
                                      sigma = results4,
                                      numPrePeriods = 13,
                                      numPostPeriods = 4,
                                      Mvec = seq(from = 0, to = 0.2, by =0.04))

delta_sd_results

createSensitivityPlot(delta_sd_results, originalResults)

##Net migration

vec2 <-c(-0.209,0.026,0.256,0.097,-0.009,-0.038,0.088,0.129,0.133,0.082,-0.043,0.036,-0.007,-1.116,-1.500,-1.560,-1.911)

work_matrix2 <- read_excel("~/net_matrix.xlsx")
results4 <-data.matrix(work_matrix2)

delta_rm_results <- 
  HonestDiD::createSensitivityResults_relativeMagnitudes(
    betahat = vec2, #coefficients
    sigma = results4, #covariance matrix
    numPrePeriods = 13, #num. of pre-treatment coefs
    numPostPeriods =4, #num. of post-treatment coefs
    Mbarvec = seq(0.5,2,by=0.5) #values of Mbar
  )

delta_rm_results

originalResults <- HonestDiD::constructOriginalCS(betahat = vec2,
                                                  sigma = results4,
                                                  numPrePeriods = 13,
                                                  numPostPeriods = 2)

HonestDiD::createSensitivityPlot_relativeMagnitudes(delta_rm_results, originalResults)


delta_sd_results <- 
  HonestDiD::createSensitivityResults(betahat = vec2,
                                      sigma = results4,
                                      numPrePeriods = 13,
                                      numPostPeriods = 4,
                                      Mvec = seq(from = 0, to = 0.2, by =0.04))

delta_sd_results

createSensitivityPlot(delta_sd_results, originalResults)

##Outflows

vec2 <-c(-0.537,-0.491,-0.492,-0.444,-0.300,-0.023,0.042,-0.002,-0.113,-0.223,-0.132,-0.127,-0.004,0.585,0.605,0.602,0.905)

work_matrix2 <- read_excel("~/work_outflows.xlsx")
results4 <-data.matrix(work_matrix2)

delta_rm_results <- 
  HonestDiD::createSensitivityResults_relativeMagnitudes(
    betahat = vec2, #coefficients
    sigma = results4, #covariance matrix
    numPrePeriods = 13, #num. of pre-treatment coefs
    numPostPeriods =4, #num. of post-treatment coefs
    Mbarvec = seq(0.5,2,by=0.5) #values of Mbar
  )

delta_rm_results

originalResults <- HonestDiD::constructOriginalCS(betahat = vec2,
                                                  sigma = results4,
                                                  numPrePeriods = 13,
                                                  numPostPeriods = 4)

HonestDiD::createSensitivityPlot_relativeMagnitudes(delta_rm_results, originalResults)


delta_sd_results <- 
  HonestDiD::createSensitivityResults(betahat = vec2,
                                      sigma = results4,
                                      numPrePeriods = 13,
                                      numPostPeriods = 4,
                                      Mvec = seq(from = 0, to = 0.1, by =0.02))

delta_sd_results

createSensitivityPlot(delta_sd_results, originalResults)

